@@ -4,8 +4,15 @@
 #![allow(dead_code)]
 #![allow(clippy::unreadable_literal)]
 
+#[cfg(all(not(feature = "update-bindings"), feature = "generate-bindings"))]
 include!(concat!(env!("OUT_DIR"), "/bindings.rs"));
 
+#[cfg(any(feature = "update-bindings", not(feature = "generate-bindings")))]
+include!(concat!(
+    env!("CARGO_MANIFEST_DIR"),
+    "/generated/bindings.rs"
+));
+
 impl Path {
     pub fn vertices(&self) -> &[[i64; 2]] {
         unsafe { std::slice::from_raw_parts(self.vertices, self.vertices_count as usize) }
